#!/bin/sh
# postinst script for benno-import-rest
#
# see: dh_installdeb(1)

set -e

# summary of how this script can be called:
#        * <postinst> `configure' <most-recently-configured-version>
#        * <old-postinst> `abort-upgrade' <new version>
#        * <conflictor's-postinst> `abort-remove' `in-favour' <package>
#          <new-version>
#        * <postinst> `abort-remove'
#        * <deconfigured's-postinst> `abort-deconfigure' `in-favour'
#          <failed-install-package> <version> `removing'
#          <conflicting-package> <version>
# for details, see http://www.debian.org/doc/debian-policy/ or
# the debian-policy package


case "$1" in
    configure)
        chown benno:www-data /etc/benno-import-rest
        chgrp benno /etc/benno-import-rest/rest.yml
        chgrp benno /etc/benno-import-rest/rest-log4j.yml
        chgrp www-data /etc/benno-import-rest/auth-storage.yml
        chmod 0550 /etc/benno-import-rest
        chmod 0640 /etc/benno-import-rest/rest.yml
        chmod 0640 /etc/benno-import-rest/rest-log4j.yml
        chmod 0640 /etc/benno-import-rest/auth-storage.yml


        if [ -d /etc/benno-web/auth.d ];then
            if [ ! -f /etc/benno-web/auth.d/90_container-storage ]; then
                echo "Add symlink to map storageurls of containers /etc/benno-web/auth.d/90_container-storage"
                ln -s /srv/benno/import-rest/auth/container-storage /etc/benno-web/auth.d/90_container-storage
            fi
        fi

        if [ -d /etc/apache2/conf-enabled ];then
            if [ ! -L /etc/apache2/conf-available/benno-import-rest.conf ];then
                ln -s /etc/benno-import-rest/apache2.conf /etc/apache2/conf-available/benno-import-rest.conf
                a2enmod cgi
                a2enconf benno-import-rest
                echo "Please restart Apache web server"
            fi
        fi
    ;;

    abort-upgrade|abort-remove|abort-deconfigure)
    ;;

    *)
        echo "postinst called with unknown argument \`$1'" >&2
        exit 1
    ;;
esac

# dh_installdeb will replace this with shell code automatically
# generated by other debhelper scripts.

# Automatically added by dh_installsystemd/13.11.4
if [ "$1" = "configure" ] || [ "$1" = "abort-upgrade" ] || [ "$1" = "abort-deconfigure" ] || [ "$1" = "abort-remove" ] ; then
	# The following line should be removed in trixie or trixie+1
	deb-systemd-helper unmask 'benno-import-rest.service' >/dev/null || true

	# was-enabled defaults to true, so new installations run enable.
	if deb-systemd-helper --quiet was-enabled 'benno-import-rest.service'; then
		# Enables the unit on first installation, creates new
		# symlinks on upgrades if the unit file has changed.
		deb-systemd-helper enable 'benno-import-rest.service' >/dev/null || true
	else
		# Update the statefile to add new symlinks (if any), which need to be
		# cleaned up on purge. Also remove old symlinks.
		deb-systemd-helper update-state 'benno-import-rest.service' >/dev/null || true
	fi
fi
# End automatically added section
# Automatically added by dh_installsystemd/13.11.4
if [ "$1" = "configure" ] || [ "$1" = "abort-upgrade" ] || [ "$1" = "abort-deconfigure" ] || [ "$1" = "abort-remove" ] ; then
	if [ -d /run/systemd/system ]; then
		systemctl --system daemon-reload >/dev/null || true
		if [ -n "$2" ]; then
			_dh_action=restart
		else
			_dh_action=start
		fi
		deb-systemd-invoke $_dh_action 'benno-import-rest.service' >/dev/null || true
	fi
fi
# End automatically added section


exit 0
